==> openshift-model-whereabouts-6.7.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OverlappingRangeIPReservationListBuilder extends OverlappingRangeIPReservationListFluentImpl<OverlappingRangeIPReservationListBuilder> implements VisitableBuilder<OverlappingRangeIPReservationList,OverlappingRangeIPReservationListBuilder>{
  public OverlappingRangeIPReservationListBuilder() {
    this(false);
  }
  public OverlappingRangeIPReservationListBuilder(Boolean validationEnabled) {
    this(new OverlappingRangeIPReservationList(), validationEnabled);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent) {
    this(fluent, false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OverlappingRangeIPReservationList(), validationEnabled);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,OverlappingRangeIPReservationList instance) {
    this(fluent, instance, false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,OverlappingRangeIPReservationList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationList instance) {
    this(instance,false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationList instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OverlappingRangeIPReservationListFluent<?> fluent;
  Boolean validationEnabled;
  public OverlappingRangeIPReservationList build() {
    OverlappingRangeIPReservationList buildable = new OverlappingRangeIPReservationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-whereabouts-6.8.0-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/OverlappingRangeIPReservationListBuilder.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OverlappingRangeIPReservationListBuilder extends OverlappingRangeIPReservationListFluent<OverlappingRangeIPReservationListBuilder> implements VisitableBuilder<OverlappingRangeIPReservationList,OverlappingRangeIPReservationListBuilder>{
  public OverlappingRangeIPReservationListBuilder() {
    this(false);
  }
  public OverlappingRangeIPReservationListBuilder(Boolean validationEnabled) {
    this(new OverlappingRangeIPReservationList(), validationEnabled);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent) {
    this(fluent, false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OverlappingRangeIPReservationList(), validationEnabled);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,OverlappingRangeIPReservationList instance) {
    this(fluent, instance, false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationListFluent<?> fluent,OverlappingRangeIPReservationList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new OverlappingRangeIPReservationList());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withItems(instance.getItems());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationList instance) {
    this(instance,false);
  }
  public OverlappingRangeIPReservationListBuilder(OverlappingRangeIPReservationList instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new OverlappingRangeIPReservationList());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withApiVersion(instance.getApiVersion());
      this.withItems(instance.getItems());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  OverlappingRangeIPReservationListFluent<?> fluent;
  Boolean validationEnabled;
  public OverlappingRangeIPReservationList build() {
    OverlappingRangeIPReservationList buildable = new OverlappingRangeIPReservationList(fluent.getApiVersion(),fluent.buildItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
